package com.mopub.mobileads;


import static com.mopub.common.logging.MoPubLog.AdapterLogEvent.LOAD_FAILED;
import static com.mopub.mobileads.MoPubInline.ADAPTER_NAME;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.Handler;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;

import com.alxad.api.AlxAdError;
import com.alxad.api.AlxNativeAD;
import com.alxad.api.AlxNativeAdListener;
import com.alxad.api.AlxNativeAdLoadListener;
import com.alxad.api.AlxNativeExpressAdListener;
import com.alxad.api.IAlxNativeInfo;
import com.mopub.common.Preconditions;
import com.mopub.common.logging.MoPubLog;
import com.mopub.nativeads.BaseNativeAd;
import com.mopub.nativeads.CustomEventNative;
import com.mopub.nativeads.NativeErrorCode;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * MoPub 原生广告适配器
 */
public class AlxNativeAdapter extends CustomEventNative {
    private static final String TAG = "AlxNativeAdapter";
    private final int AD_STYLE_TYPE_EXPRESS = 0;
    private final int AD_STYLE_TYPE_NATIVE = 1;
    private String mUnitid = "";

    private AlxNativeAD mAdObj;
    private int mImageWidth; //请求广告图的宽度：单位px
    private int mImageHeight; //请求广告图的高度: 单位px
    private int mAdStyleType = AD_STYLE_TYPE_NATIVE; //广告样式类型： 0：是模版广告，1是原生广告

    private CustomEventNativeListener mCustomEventNativeListener;

    private AlxServicesAdapterConfiguration mAlxServicesAdapterConfiguration;

    public AlxNativeAdapter() {
        Log.i(TAG, "construct");
        mAlxServicesAdapterConfiguration = new AlxServicesAdapterConfiguration();
    }

    @Override
    protected void loadNativeAd(Context context, CustomEventNativeListener customEventNativeListener, Map<String, Object> localExtras, Map<String, String> serverExtras) {
        Log.i(TAG, "loadNativeAd");
        Preconditions.checkNotNull(context);
        Preconditions.checkNotNull(customEventNativeListener);
//        Preconditions.checkNotNull(localExtras);
        Preconditions.checkNotNull(serverExtras);

        mCustomEventNativeListener = customEventNativeListener;

        parseServiceString(serverExtras);
        if (TextUtils.isEmpty(mUnitid)) {
            MoPubLog.log(getAdNetworkId(), LOAD_FAILED, ADAPTER_NAME,
                    MoPubErrorCode.NETWORK_NO_FILL.getIntCode(),
                    MoPubErrorCode.NETWORK_NO_FILL);
            if (mCustomEventNativeListener != null) {
                mCustomEventNativeListener.onNativeAdFailed(NativeErrorCode.NETWORK_NO_FILL);
            }
            return;
        }
        loadAds(context);
        mAlxServicesAdapterConfiguration.setCachedInitializationParameters(context, serverExtras);
    }

    private void parseServiceString(Map<String, String> extras) {
        try {
            if (extras == null || extras.size() == 0) {
                return;
            }
            Log.d(TAG, "--------    extras  start   ---------  ");
            mUnitid = extras.get("unitid");
            Log.d(TAG, "unitid   " + mUnitid);
            Log.d(TAG, "--------    extras  end   ---------  ");
        } catch (Exception e) {
            Log.e(TAG, "parseServiceString error:" + e.getMessage());
        }
    }

    private void loadAds(Context context) {
        Log.i(TAG, "loadAds");
        AlxNativeAdLoadListener loadListener = new AlxNativeAdLoadListener() {
            @Override
            public void onAdLoadedFail(final int errorCode, String errorMsg) {
                Log.i(TAG, "onAdLoadedFail:" + errorCode + ";" + errorMsg);
                MoPubLog.log(getAdNetworkId(), LOAD_FAILED, ADAPTER_NAME, "Failed to " +
                        "load Google native ad with message: " + errorMsg);

                if (mCustomEventNativeListener != null) {
                    mCustomEventNativeListener.onNativeAdFailed(mapErrorCode(errorCode));
                }
            }

            @Override
            public void onAdLoaded(final List<IAlxNativeInfo> ads) {
                Log.i(TAG, "onAdLoaded");

                if (ads == null || ads.isEmpty()) {
                    if (mCustomEventNativeListener != null) {
                        mCustomEventNativeListener.onNativeAdFailed(NativeErrorCode.EMPTY_AD_RESPONSE);
                    }
                    return;
                }

                AlgorixNativeAd result = null;
                try {
                    IAlxNativeInfo bean = ads.get(0);
                    if (bean != null) {
                        result = new AlgorixNativeAd(bean);
                    }
                } catch (Exception e) {
                    Log.e(TAG, e.getMessage());
                    e.printStackTrace();
                    result = null;
                }

                if (result != null) {
                    if (mCustomEventNativeListener != null) {
                        Log.i(TAG, "onAdLoaded:listener-ok");
                        mCustomEventNativeListener.onNativeAdLoaded(result);
                    }
                } else {
                    if (mCustomEventNativeListener != null) {
                        Log.i(TAG, "onAdLoaded:listener-error");
                        mCustomEventNativeListener.onNativeAdFailed(NativeErrorCode.NATIVE_ADAPTER_NOT_FOUND);
                    }
                }

            }
        };


        mAdObj = new AlxNativeAD(context, mUnitid);
        AlxNativeAD.AlxAdSlot adSlot = new AlxNativeAD.AlxAdSlot();
        int adStyleType;
        if (mAdStyleType == AD_STYLE_TYPE_NATIVE) {
            adStyleType = AlxNativeAD.AlxAdSlot.TYPE_NATIVE_AD;
        } else {
            adStyleType = AlxNativeAD.AlxAdSlot.TYPE_EXPRESS_AD;
        }
        adSlot.setAdStyleType(adStyleType);
//        if (mImageWidth > 1 && mImageHeight > 1) {
//            adSlot.setAdImageSize(mImageWidth, mImageHeight);
//        }
        mAdObj.load(adSlot, loadListener);
    }


    public static class AlgorixNativeAd extends BaseNativeAd {
        private IAlxNativeInfo mAlxAd;
        private Map<String, Object> mExtras;

        public AlgorixNativeAd(IAlxNativeInfo bean) {
            super();
            mAlxAd = bean;
            mExtras = new HashMap<String, Object>();
            bindListener();
        }

        @Override
        public void prepare(@NonNull View view) {
            Log.i(TAG, "prepare");
        }

        @Override
        public void clear(@NonNull View view) {
            Log.i(TAG, "clear");
            Preconditions.checkNotNull(view);
            if (mAlxAd != null) {
                mAlxAd.destroy();
            }
        }

        @Override
        public void destroy() {
            mAlxAd.destroy();
        }

        public View getAdView() {
            if (mAlxAd != null) {
                mAlxAd.getExpressView();
            }
            return null;
        }

        public Bitmap getAdLogo() {
            if (mAlxAd != null) {
                return mAlxAd.getAdLogo();
            }
            return null;
        }

        public final String getTitle() {
            if (mAlxAd != null) {
                return mAlxAd.getTitle();
            }
            return null;
        }

        public final String getText() {
            if (mAlxAd != null) {
                return mAlxAd.getDescription();
            }
            return null;
        }

        public final String getCallToAction() {
            if (mAlxAd != null) {
                return mAlxAd.getInteractionText();
            }
            return null;
        }

        public final String getIconImageUrl() {
            if (mAlxAd != null) {
                return mAlxAd.getIconUrl();
            }
            return null;
        }

        public final String getMainImageUrl() {
            if (mAlxAd != null) {
                return mAlxAd.getImageUrl();
            }
            return null;
        }

        final public Map<String, Object> getExtras() {
            return new HashMap<String, Object>(mExtras);
        }

        void registerViewForInteraction(ViewGroup view, List<View> clickViews) {
            if (mAlxAd != null) {
                mAlxAd.registerViewForInteraction(view, clickViews);
            }
        }

        void registerViewForInteraction(ViewGroup view, View clickViews) {
            if (mAlxAd != null) {
                mAlxAd.registerViewForInteraction(view, clickViews);
            }
        }

        private void bindListener() {
            if (mAlxAd == null) {
                return;
            }
            if (mAlxAd.isExpressAd()) {
                mAlxAd.setAlxNativeAdListener(new AlxNativeExpressAdListener() {
                    @Override
                    public void onAdClose() {

                    }

                    @Override
                    public void onRenderFail(int code, String msg) {

                    }

                    @Override
                    public void onRenderSuccess(View view) {

                    }

                    @Override
                    public void onAdClick() {
                        notifyAdClicked();
                    }

                    @Override
                    public void onAdShow() {
//                        MoPubLog.log(getAdNetworkId(), SHOW_SUCCESS, ADAPTER_NAME);
                        notifyAdImpressed();
                    }
                });
            } else {
                mAlxAd.setAlxNativeAdListener(new AlxNativeAdListener() {
                    @Override
                    public void onAdClick() {
                        notifyAdClicked();
                    }

                    @Override
                    public void onAdShow() {
                        notifyAdImpressed();
                    }

                    @Override
                    public void onAdClose() {

                    }
                });
            }

        }
    }


    private String getAdNetworkId() {
        return mUnitid == null ? "" : mUnitid;
    }

    private NativeErrorCode mapErrorCode(int error) {
        switch (error) {
            case AlxAdError.ERR_NETWORK:
                return NativeErrorCode.NETWORK_INVALID_STATE;
            case AlxAdError.ERR_NO_FILL:
                return NativeErrorCode.NETWORK_NO_FILL;
            case AlxAdError.ERR_VAST_ERROR:
            case AlxAdError.ERR_PARSE_AD:
                return NativeErrorCode.INVALID_RESPONSE;
            case AlxAdError.ERR_SERVER:
                return NativeErrorCode.SERVER_ERROR_RESPONSE_CODE;
            case AlxAdError.ERR_UNKNOWN:
                return NativeErrorCode.NATIVE_ADAPTER_NOT_FOUND;
            default:
                return NativeErrorCode.UNSPECIFIED;
        }
    }

}