package com.alxad.alx.demo;


import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.TextView;

import androidx.appcompat.app.AppCompatActivity;

import com.alxad.AppConfig;
import com.alxad.R;
import com.alxad.api.AlxNativeAD;
import com.alxad.api.AlxNativeAdListener;
import com.alxad.api.AlxNativeAdLoadListener;
import com.alxad.api.AlxNativeExpressAdListener;
import com.alxad.api.IAlxNativeInfo;
import com.bumptech.glide.Glide;

import java.util.ArrayList;
import java.util.List;


/**
 * 原生广告——在ListView 中显示
 */
public class AlxNativeListViewActivity extends AppCompatActivity {
    private final String TAG = "AlxNativeListDemo";

    private MyAdapter mAdapter;
    private int mAdStyleType;
    private AlxNativeAD mNativeAd;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_alx_native_listview);
        initView();
        initData();
        loadAd();
    }

    private void initView() {
        ListView mListView = (ListView) findViewById(R.id.listview);
        mAdapter = new MyAdapter(this);
        mListView.setAdapter(mAdapter);
    }

    private void initData() {
        Intent intent = getIntent();
        boolean value = intent.getBooleanExtra(AlxNativeDemoActivity.EXTRA_AD_TYPE, true);
        if (value) {
            mAdStyleType = AlxNativeAD.AlxAdSlot.TYPE_EXPRESS_AD;
        } else {
            mAdStyleType = AlxNativeAD.AlxAdSlot.TYPE_NATIVE_AD;
        }
    }

    private void loadAd() {
        //初始化广告位。仅调用一次。
        mNativeAd = new AlxNativeAD(this, AppConfig.ALX_NATIVE_AD_PID);
        AlxNativeAD.AlxAdSlot adSlot = new AlxNativeAD.AlxAdSlot()
                .setAdStyleType(mAdStyleType);// **必传，表示请求的模板广告还是原生广告，AdSlot.TYPE_EXPRESS_AD：模板广告 ； AdSlot.TYPE_NATIVE_AD：原生广告**
        mNativeAd.load(adSlot, new AlxNativeAdLoadListener() {
            @Override
            public void onAdLoadedFail(int errorCode, String errorMsg) {
                Log.i(TAG, "onAdLoadedFail:" + getThreadName() + " " + errorCode + ";" + errorMsg);
            }

            @Override
            public void onAdLoaded(final List<IAlxNativeInfo> ads) {
                Log.i(TAG, "onAdLoaded:" + getThreadName());

                if (ads == null) {
                    return;
                }
                List<IAlxNativeInfo> list = new ArrayList<>();
                for (IAlxNativeInfo item : ads) {
                    for (int i = 0; i < 5; i++) {
                        list.add(null);
                    }
                    list.add(item);
                }
                for (int i = 0; i < 12; i++) {
                    list.add(null);
                }
                mAdapter.setRefreshData(list);
            }
        });
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mNativeAd != null) {
            mNativeAd.destroy();
        }
    }

    private String getThreadName() {
        return Thread.currentThread().getName();
    }

    private class MyAdapter extends BaseAdapter {

        private static final int ITEM_VIEW_TYPE_NORMAL = 0;
        private static final int ITEM_VIEW_TYPE_NATIVE_AD = 1;
        private static final int ITEM_VIEW_TYPE_EXPRESS_AD = 2;

        private Context mContext;
        private List<IAlxNativeInfo> mList;

        public MyAdapter(Context context) {
            mContext = context;
        }

        public void setRefreshData(List<IAlxNativeInfo> list) {
            if (list == null) {
                if (mList == null) {
                    mList = new ArrayList<>();
                } else {
                    mList.clear();
                }
                notifyDataSetChanged();
                return;
            }
            if (mList == null) {
                mList = new ArrayList<>();
            }
            mList.clear();
            mList.addAll(list);
            notifyDataSetChanged();
        }


        @Override
        public int getCount() {
            return (mList == null || mList.isEmpty()) ? 0 : mList.size(); // for test
        }

        @Override
        public IAlxNativeInfo getItem(int position) {
            return mList.get(position);
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public int getViewTypeCount() {
            return 3;
        }

        @Override
        public int getItemViewType(int position) {
            IAlxNativeInfo bean = getItem(position);
            if (bean == null) {
                return ITEM_VIEW_TYPE_NORMAL;
            }
            if (bean.isExpressAd()) {
                return ITEM_VIEW_TYPE_EXPRESS_AD;
            } else {
                return ITEM_VIEW_TYPE_NATIVE_AD;
            }
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            switch (getItemViewType(position)) {
                case ITEM_VIEW_TYPE_NATIVE_AD:
                    return getBigImgViewAd(convertView, parent, position);
                case ITEM_VIEW_TYPE_EXPRESS_AD:
                    return getExpressViewAd(convertView, parent, position);
                default:
                    return getNormalView(convertView, parent, position);
            }
        }

        /**
         * 自渲染广告
         *
         * @param convertView
         * @param parent
         * @param position
         * @return
         */
        private View getBigImgViewAd(View convertView, ViewGroup parent, int position) {
            AdBigViewHolder holder;
            if (convertView == null) {
                holder = new AdBigViewHolder();
                convertView = LayoutInflater.from(mContext).inflate(R.layout.adapter_native_big_img, parent, false);
                holder.mIvLogo = (ImageView) convertView.findViewById(R.id.iv_logo);
                holder.mIvIcon = (ImageView) convertView.findViewById(R.id.iv_ad_icon);
                holder.mTitle = (TextView) convertView.findViewById(R.id.tv_ad_title);
                holder.mDescription = (TextView) convertView.findViewById(R.id.tv_ad_desc);
                holder.mSource = (Button) convertView.findViewById(R.id.adapter_ad_source);
                holder.mClose = (ImageView) convertView.findViewById(R.id.adapter_ad_close);
                holder.mBigImg = (ImageView) convertView.findViewById(R.id.iv_image);
                convertView.setTag(holder);
            } else {
                holder = (AdBigViewHolder) convertView.getTag();
            }
            final IAlxNativeInfo bean = getItem(position);
            holder.mIvLogo.setImageBitmap(bean.getAdLogo());
            holder.mTitle.setText(bean.getTitle());
            holder.mDescription.setText(bean.getDescription());
            holder.mSource.setText(bean.getInteractionText());
            Glide.with(mContext).load(bean.getImageUrl()).into(holder.mBigImg);
            Glide.with(mContext).load(bean.getIconUrl()).into(holder.mIvIcon);

            bean.setAlxNativeAdListener(new AlxNativeAdListener() {
                @Override
                public void onAdClick() {
                    Log.i(TAG, "onAdClick:" + getThreadName());
                }

                @Override
                public void onAdShow() {
                    Log.i(TAG, "onAdShow:" + getThreadName());
                }

                @Override
                public void onAdClose() {
                    Log.i(TAG, "onAdClose:" + getThreadName());
                    bean.destroy();
                    mList.remove(bean);
                    notifyDataSetChanged();
                }
            });

            List<View> clickView = new ArrayList<>();
            clickView.add(holder.mBigImg);
            clickView.add(holder.mTitle);
            clickView.add(holder.mSource);
            bean.registerViewForInteraction((ViewGroup) convertView, clickView);
            bean.setCloseView(holder.mClose);

//            holder.mClose.setOnClickListener(new View.OnClickListener() {
//                @Override
//                public void onClick(View v) {
//                    mList.remove(bean);
//                    notifyDataSetChanged();
//                }
//            });
            return convertView;
        }

        /**
         * 模版广告
         *
         * @param convertView
         * @param parent
         * @param position
         * @return
         */
        private View getExpressViewAd(View convertView, ViewGroup parent, final int position) {
            final AdExpressViewHolder holder;
            if (convertView == null) {
                holder = new AdExpressViewHolder();
                convertView = LayoutInflater.from(mContext).inflate(R.layout.adapter_native_express, parent, false);
                holder.mAdContainerView = (FrameLayout) convertView.findViewById(R.id.item_express);
                convertView.setTag(holder);
            } else {
                holder = (AdExpressViewHolder) convertView.getTag();
            }
            final IAlxNativeInfo bean = getItem(position);

            bean.setAlxNativeAdListener(new AlxNativeExpressAdListener() {
                @Override
                public void onAdClose() {
                    Log.i(TAG, "onAdClose:" + getThreadName());
                    bean.destroy();
                    mList.remove(bean);
                    notifyDataSetChanged();
                }

                @Override
                public void onRenderFail(int code, String msg) {
                    Log.i(TAG, "onRenderFail:" + getThreadName() + "::" + code + ";" + msg);
                }

                @Override
                public void onRenderSuccess(View view) {
                    Log.i(TAG, "onRenderSuccess:" + getThreadName());
                }

                @Override
                public void onAdClick() {
                    Log.i(TAG, "onAdClicked:" + getThreadName());
                }

                @Override
                public void onAdShow() {
                    Log.i(TAG, "onAdShow:" + getThreadName());
                }
            });
            View expressView = bean.getExpressView();
            if (holder.mAdContainerView != null && expressView != null) {
                if (expressView.getParent() != null) {
                    if (expressView.getParent() instanceof ViewGroup) {
                        ViewGroup groupView = (ViewGroup) expressView.getParent();
                        groupView.removeAllViews();
                    }
                }
                if (expressView.getParent() == null) {
                    holder.mAdContainerView.removeAllViews();
                    FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);
                    holder.mAdContainerView.addView(expressView, layoutParams);
                }
                bean.render();
            }
            return convertView;
        }

        private View getNormalView(View convertView, ViewGroup parent, int position) {
            NormalViewHolder holder;
            if (convertView == null) {
                holder = new NormalViewHolder();
                convertView = LayoutInflater.from(mContext).inflate(R.layout.adapter_native_normal, parent, false);
                holder.mIvIcon = (ImageView) convertView.findViewById(R.id.item_icon);
                holder.mTvTitle = (TextView) convertView.findViewById(R.id.item_title);
                holder.mTvDesc = (TextView) convertView.findViewById(R.id.item_desc);
                convertView.setTag(holder);
            } else {
                holder = (NormalViewHolder) convertView.getTag();
            }
            holder.mTvTitle.setText("信息流测试标题广告-ListView:  " + position);
            holder.mTvDesc.setText("信息流测试描述广告-ListView:  " + position);
            return convertView;
        }

    }

    private static class AdBigViewHolder extends AdViewHolder {
        ImageView mBigImg;
    }

    private static class AdExpressViewHolder extends AdViewHolder {
        FrameLayout mAdContainerView;
    }

    private static class AdViewHolder {
        ImageView mIvLogo;
        ImageView mIvIcon;
        TextView mTitle;
        TextView mDescription;
        Button mSource;
        ImageView mClose;
    }

    private static class NormalViewHolder {
        ImageView mIvIcon;
        TextView mTvTitle;
        TextView mTvDesc;
    }


    /**
     * 获取屏幕宽度
     *
     * @param context 上下文
     * @return 屏幕宽度
     */
    public static int getScreenWidth(Context context) {
        DisplayMetrics dm = context.getResources().getDisplayMetrics();
        return dm.widthPixels;
    }

}